/*----------------------------------------------------------------------
copyright (c) 2008 Georget Fabien

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
--------------------------------------------------------------------------
File : InfoTab.cpp
Program : gt2n
Date : 16/06/08
--------------------------------------------------------------------------
Nature : C++ file for the information widget
--------------------------------------------------------------------------*/

#include <QLabel>
#include <QMenu>
#include <QWidget>
#include <QPushButton>
#include <QGridLayout>
#include <QContextMenuEvent>
#include <QDockWidget>

#include "InfoTab.h"

InfoTab::InfoTab():QWidget()
{

}

InfoTab::InfoTab(QDockWidget *dock, MainWindow *mainWind):QWidget(dock)
{
    fenPrincipale = mainWind;
    createAction();

    // widget
      // name
      QLabel *nameLabel = new QLabel("Name :");
      name_info = new QLabel; 
      //firmware version
      QLabel *namefv = new QLabel("Firmware version :");
      firm_info = new QLabel;       
      //protocole version
      QLabel *namept = new QLabel("Protocol version :");
      prot_info = new QLabel; 
      // battery level
      QLabel *namebat = new QLabel("Battery level :");
      batt_info = new QLabel;       
      // bluetooth adress
      QLabel *namead = new QLabel("Address bluetooth :");
      adbt_info = new QLabel;
      //refresh button
      QPushButton *nameButton = new QPushButton("Refresh",this);
      connect(nameButton,SIGNAL(clicked()),this,SLOT(s_getInfo()));
      
       // Layout
      QGridLayout *infoLayout = new QGridLayout;
      infoLayout->addWidget(nameLabel,0,0);
      infoLayout->addWidget(name_info,0,1,1,2);
      infoLayout->addWidget(namefv,1,0);
      infoLayout->addWidget(firm_info,1,1,1,2);  
      infoLayout->addWidget(namept,2,0);
      infoLayout->addWidget(prot_info,2,1,1,2);         
      infoLayout->addWidget(namebat,3,0);
      infoLayout->addWidget(batt_info,3,1,1,2); 
      infoLayout->addWidget(namead,4,0);
      infoLayout->addWidget(adbt_info,4,1,1,2);              
      infoLayout->addWidget(nameButton,5,1);      
      infoLayout->setRowStretch(6,2);
      this->setLayout(infoLayout);
}

/* -----------------------------------------------------------------------*\
|			       PUBLIC                                      |
\*------------------------------------------------------------------------*/

// Getting information from the NXT brick :
void InfoTab::getInfo()
{
 info = fenPrincipale->getInfo();
 if (abs(info.mV) < 100000) {afficheInfo();}
}

void InfoTab::afficheInfo()
{ 
  QString str;
  name_info->setText(info.nme); 
  firm_info->setText(QString(str.setNum(info.fMv)) + "." + QString(str.setNum(info.fmv)));
  prot_info->setText(QString(str.setNum(info.pMv)) + "." + QString(str.setNum(info.pmv)));
  batt_info->setText(str.setNum(info.mV) + " mV");
  adbt_info->setText(QString(str.setNum(info.bt[0],16))+":"+QString(str.setNum(info.bt[1],16))+":"+QString(str.setNum(info.bt[2],16))+":"+QString(str.setNum(info.bt[3],16))+":"+QString(str.setNum(info.bt[4],16))+":"+QString(str.setNum(info.bt[5],16)));
}

void InfoTab::effacerInfo()
{ 
  name_info->setText(""); 
  firm_info->setText("");
  prot_info->setText("");
  batt_info->setText("");
  adbt_info->setText("");
}

// a method to enable/disable action when (dis)connecting the brick
void InfoTab::actEnableConnect(bool boolean)
{
  refreshAct->setEnabled(boolean);
  renameAct->setEnabled(boolean);
  disconnectAct->setEnabled(boolean);
  
  connectAct->setEnabled(!boolean);

}

/* -----------------------------------------------------------------------*\
|			       PROTECTED                                   |
\*------------------------------------------------------------------------*/

void InfoTab::contextMenuEvent(QContextMenuEvent *event)
{
  QMenu menu(this);
  menu.addAction(connectAct);
  menu.addAction(disconnectAct);
  menu.addSeparator();
  menu.addAction(refreshAct);
  menu.addAction(renameAct);
  menu.exec(event->globalPos());
}


/* -----------------------------------------------------------------------*\
|			       SLOT                                        |
\*------------------------------------------------------------------------*/

void InfoTab::s_getInfo(){getInfo();}


/* -----------------------------------------------------------------------*\
|			       PRIVATE                                     |
\*------------------------------------------------------------------------*/

void InfoTab::createAction()
{
   refreshAct = new QAction(tr("&Refresh"),this);
    refreshAct->setStatusTip(tr("Refresh information"));
    refreshAct->setEnabled(false);
    QObject::connect(refreshAct, SIGNAL(triggered()), this, SLOT(s_getInfo()));

   renameAct = new QAction(tr("Re&name"),this);
    renameAct->setStatusTip(tr("Rename the brick"));
    renameAct->setEnabled(false);
    QObject::connect(renameAct, SIGNAL(triggered()), fenPrincipale, SLOT(s_renameBrick()));

   connectAct = new QAction(tr("&Connect"),this);
    connectAct->setStatusTip(tr("Connect the brick"));
    connect(connectAct, SIGNAL(triggered()),fenPrincipale, SLOT(s_connectBrick()));

    disconnectAct = new QAction(tr("&Disconnect"),this);
      disconnectAct->setStatusTip(tr("Disconnect the brick"));
      disconnectAct->setEnabled(false);
      QObject::connect(disconnectAct, SIGNAL(triggered()), fenPrincipale, SLOT(s_disconnectBrick()));

}

